import json
import os
import subprocess
import pandas as pd


def checkawsprofile():
    if ("AWS_PROFILE" in os.environ.keys()) or (("AWS_ACCESS_KEY_ID" in os.environ.keys()) and ("AWS_SECRET_ACCESS_KEY" in os.environ.keys())):
        return 1
    else:
        print("Please setup AWS PROFILE or export your ACCESS KEY and SECRET KEY First.....")
        quit()
        



from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

VERSION = '0.8.0'
DESCRIPTION = 'Comparing RDS parameter group in AWS account'
LONG_DESCRIPTION = 'A package that allows to compare RDS instance and RDS cluster custom parameter group to their default family parameter group.'

# Setting up
setup(
    name="comparerdspg",
    version=VERSION,
    author="Tanmay Varade",
    author_email="<tanmayvarade235@gmail.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    url="https://github.com/tanmay6414/comparerdspg",
    install_requires=['pandas'],
    keywords=['python', 'compare', 'RDS', 'parameter', 'group', 'AWS', 'devops'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)